@@ -19,7 +19,7 @@ import pandas
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 
-PHOOTONICS_URL = 'http://localhost:5000'
+PHOOTONICS_URL = 'http://0.0.0.0:5000'
 
 
 def scan():
